@@ -10,6 +10,6 @@
 from pyutilib.component.core import PluginGlobals
 PluginGlobals.push_env("pca")
 
-from executable import *
+from pyutilib.component.executables.executable import *
 
 PluginGlobals.pop_env()
